pub struct AgentProfileRevision {Show 17 fields
pub id: String,
pub profile_id: String,
pub revision: u64,
pub persona: String,
pub purpose: String,
pub output_policy: Option<Struct>,
pub runtime_policy: Option<RuntimePolicy>,
pub skills: HashMap<String, String>,
pub skill_packs: HashMap<String, String>,
pub plugins: HashMap<String, PluginConfig>,
pub memory: Option<MemoryPolicy>,
pub knowledge_bindings: Vec<KnowledgeBinding>,
pub subagent: Option<CapabilityPolicy>,
pub collaboration: Option<CapabilityPolicy>,
pub name: String,
pub avatar: String,
pub description: String,
}Fields
id: Stringprofile_id: Stringrevision: u64persona: Stringpurpose: Stringoutput_policy: Option<Struct>runtime_policy: Option<RuntimePolicy>skills: HashMap<String, String>skill_packs: HashMap<String, String>plugins: HashMap<String, PluginConfig>memory: Option<MemoryPolicy>knowledge_bindings: Vec<KnowledgeBinding>subagent: Option<CapabilityPolicy>collaboration: Option<CapabilityPolicy>name: Stringavatar: Stringdescription: StringTrait Implementations
Sourceimpl Clone for AgentProfileRevision
impl Clone for AgentProfileRevision
Sourcefn clone(&self) -> AgentProfileRevision
fn clone(&self) -> AgentProfileRevision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentProfileRevision
impl Debug for AgentProfileRevision
Sourceimpl Default for AgentProfileRevision
impl Default for AgentProfileRevision
Sourceimpl Message for AgentProfileRevision
impl Message for AgentProfileRevision
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AgentProfileRevision
impl PartialEq for AgentProfileRevision
impl StructuralPartialEq for AgentProfileRevision