pub struct ResolveInteractionRequest {
pub interaction_id: String,
pub resolution: i32,
pub payload: Option<Value>,
}Fields
interaction_id: Stringresolution: i32payload: Option<Value>Implementations
Sourceimpl ResolveInteractionRequest
impl ResolveInteractionRequest
Sourcepub fn resolution(&self) -> InteractionResolutionKind
pub fn resolution(&self) -> InteractionResolutionKind
Returns the enum value of resolution, or the default if the field is set to an invalid enum value.
Sourcepub fn set_resolution(&mut self, value: InteractionResolutionKind)
pub fn set_resolution(&mut self, value: InteractionResolutionKind)
Sets resolution to the provided enum value.