pub struct RunOptions {
pub profile_revision_id: Option<String>,
pub model: Option<String>,
pub reasoning: Option<String>,
pub timezone: Option<String>,
pub web_search: Option<bool>,
pub collaboration: String,
pub page_context: Option<Value>,
}Fields
profile_revision_id: Option<String>model: Option<String>reasoning: Option<String>timezone: Option<String>web_search: Option<bool>collaboration: String[valid: auto | single | collaborate]
page_context: Option<Value>Implementations
Sourceimpl RunOptions
impl RunOptions
Sourcepub fn profile_revision_id(&self) -> &str
pub fn profile_revision_id(&self) -> &str
Returns the value of profile_revision_id, or the default value if profile_revision_id is unset.
Sourcepub fn model(&self) -> &str
pub fn model(&self) -> &str
Returns the value of model, or the default value if model is unset.
Sourcepub fn reasoning(&self) -> &str
pub fn reasoning(&self) -> &str
Returns the value of reasoning, or the default value if reasoning is unset.
Sourcepub fn timezone(&self) -> &str
pub fn timezone(&self) -> &str
Returns the value of timezone, or the default value if timezone is unset.
Sourcepub fn web_search(&self) -> bool
pub fn web_search(&self) -> bool
Returns the value of web_search, or the default value if web_search is unset.