pub struct LocaleVariant {
pub id: String,
pub space_id: String,
pub source_node_id: String,
pub target_node_id: String,
pub source_revision_id: String,
pub target_revision_id: String,
pub target_locale: String,
pub expected_target_revision: u64,
pub workflow_instance_id: String,
pub status: i32,
pub expected_target_revision_id: String,
}Fields
id: Stringspace_id: Stringsource_node_id: Stringtarget_node_id: Stringsource_revision_id: Stringtarget_revision_id: Stringtarget_locale: Stringexpected_target_revision: u64workflow_instance_id: Stringstatus: i32expected_target_revision_id: StringImplementations
Sourceimpl LocaleVariant
impl LocaleVariant
Sourcepub fn status(&self) -> TranslationStatus
pub fn status(&self) -> TranslationStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TranslationStatus)
pub fn set_status(&mut self, value: TranslationStatus)
Sets status to the provided enum value.