pub struct RevisionIndexState {
pub status: i32,
pub error: String,
}Fields
status: i32error: StringImplementations
Sourceimpl RevisionIndexState
impl RevisionIndexState
Sourcepub fn status(&self) -> RevisionIndexStatus
pub fn status(&self) -> RevisionIndexStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: RevisionIndexStatus)
pub fn set_status(&mut self, value: RevisionIndexStatus)
Sets status to the provided enum value.