pub struct ControlInstanceRequest {
pub instance_id: String,
pub action: i32,
pub reason: String,
pub action_id: Option<String>,
}Fields
instance_id: Stringaction: i32reason: Stringaction_id: Option<String>Implementations
Sourceimpl ControlInstanceRequest
impl ControlInstanceRequest
Sourcepub fn action(&self) -> InstanceControlAction
pub fn action(&self) -> InstanceControlAction
Returns the enum value of action, or the default if the field is set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: InstanceControlAction)
pub fn set_action(&mut self, value: InstanceControlAction)
Sets action to the provided enum value.